@@ -1202,8 +1202,8 @@ class WordToken(models.Model):
             out = {'Preceding': self.getPreviousContext(),
                     'Following': self.getFollowingContext(),
                     'Word': str(self.WordType),
-                    'NFormants': self.Dialog.Speaker.NumFormants,
-                    'Ceiling': self.Dialog.Speaker.Ceiling,
+                    'NFormants': self.getNFormants(),
+                    'Ceiling': self.getCeiling(),
                     'TokenID': self.pk,
                     'Contextual': cont,
                     'Lexical':lex,
