@@ -236,7 +236,8 @@ def token_details(request,tokenNum):
             request.method = 'GET'
     token.createPictures()
     form = RedoSpecGramForm()
-    return render(request,'buckeyebrowser/detail.html',{'Token':token,'form':form})
+    output = token.get_details()
+    return render(request,'buckeyebrowser/detail.html',{'output':output,'form':form})
 
 
 
